stravalib.util.limiter.get\_seconds\_until\_next\_quarter
=========================================================

.. currentmodule:: stravalib.util.limiter

.. autofunction:: get_seconds_until_next_quarter
